ENV_VAR__AUTH__TARGET_SERVER__CACHE_SERVICE__KEY_NAME  = "AUTH__TARGET_SERVER__CACHE_SERVICE__KEY_NAME"
ENV_VAR__AUTH__TARGET_SERVER__CACHE_SERVICE__KEY_VALUE = "AUTH__TARGET_SERVER__CACHE_SERVICE__KEY_VALUE"
ENV_VAR__URL__TARGET_SERVER__CACHE_SERVICE             = "URL__TARGET_SERVER__CACHE_SERVICE"