ENV_VAR__CACHE__SERVICE__STORAGE_MODE      = 'CACHE__SERVICE__STORAGE_MODE'
ENV_VAR__CACHE__SERVICE__LOCAL_DISK_PATH   = 'CACHE__SERVICE__LOCAL_DISK_PATH'
ENV_VAR__CACHE__SERVICE__SQLITE_PATH       = 'CACHE__SERVICE__SQLITE_PATH'
ENV_VAR__CACHE__SERVICE__ZIP_PATH          = 'CACHE__SERVICE__ZIP_PATH'
